@@ -322,11 +322,11 @@ def best_m_n_min_alpha_reg(forest, c_dict):
                                                no_of_treat)
                 mse_oob[j] += tree_mse     # Add MSE to MSE of forest j
         if np.any(trees_without_oob) > 0:
-            for j, _ in enumerate(trees_without_oob):
-                if trees_without_oob[j] > 0:
+            for j, trees_without_oob_j in enumerate(trees_without_oob):
+                if trees_without_oob_j > 0:
                     mse_oob[j] = mse_oob[j] * (
                         c_dict['boot'] / (c_dict['boot']
-                                          - trees_without_oob[j]))
+                                          - trees_without_oob_j))
         min_i = np.argmin(mse_oob)
         mse_oob = mse_oob / c_dict['boot']
         if not isinstance(c_dict['grid_n_min'], (list, tuple, np.ndarray)):
