@@ -26,6 +26,7 @@ from mcf import mcf_cs_functions as mcf_cs
 from mcf import mcf_weight_functions as mcf_w
 from mcf import mcf_ate_functions as mcf_ate
 from mcf import mcf_gate_functions as mcf_gate
+from mcf import mcf_gate_tables_functions as mcf_gate_tables
 from mcf import mcf_iate_functions as mcf_iate
 from mcf import mcf_iate_add_functions as mcf_iate_add
 from mcf import mcf_forest_add_functions as mcf_forest_add
@@ -52,8 +53,8 @@ def modified_causal_forest(
         iate_se_flag=True, indata=None, knn_flag=True, knn_min_k=10,
         knn_const=1, l_centering=True, l_centering_share=0.25,
         l_centering_cv_k=5, l_centering_new_sample=False,
-        l_centering_replication=True, m_min_share=-1,
-        m_max_share=-1, m_grid=2, m_random_poisson=True,
+        l_centering_replication=True, l_centering_undo_iate=True,
+        m_min_share=-1, m_max_share=-1, m_grid=2, m_random_poisson=True,
         match_nn_prog_score=True, max_cats_z_vars=None, max_weight_share=0.05,
         mce_vart=1, min_dummy_obs=10,  mp_parallel=None,
         n_min_grid=1, n_min_min=-1, n_min_max=-1, nn_main_diag_only=False,
@@ -75,14 +76,15 @@ def modified_causal_forest(
         support_check=1, support_min_p=None, support_quantil=1,
         support_max_del_train=0.5, support_adjust_limits=None, train_mcf=True,
         variable_importance_oob=False, weighted=False,
-        _share_forest_sample=0.5, _weight_as_sparse=True, _mp_with_ray=True,
+        _share_forest_sample=0.5, _weight_as_sparse=True,
         _mp_vim_type=None, _mp_weights_type=1, _mp_weights_tree_batch=None,
         _verbose=True, _fontsize=2, _descriptive_stats=True,
         _no_filled_plot=20, _show_plots=True,
         _smaller_sample=0, _with_output=True, _dpi=500,
         _max_cats_cont_vars=None, _max_save_values=50,
         _seed_sample_split=67567885, _mp_ray_del=None,
-        _mp_ray_shutdown=None, _mp_ray_objstore_multiplier=None):
+        _mp_ray_shutdown=None, _mp_ray_objstore_multiplier=None,
+        _return_iate_sp=False):
     """Compute the honest causal/random forest (based on mcf)."""
     freeze_support()
     time1 = time.time()
@@ -92,8 +94,8 @@ def modified_causal_forest(
     _obs_by_obs = False      # Compute IATE obs by obs or in chuncks
     _max_elements_per_split = 100 * 10e5  # reduce if breakdown (weights)
     _load_old_forest = False  # Useful for testing to save time
+    _mp_with_ray = True       # Is not stable without ray
     _no_ray_in_forest_building = False
-    _l_centering_uncenter = False  # Not yet implemented
 
 # Collect vars in a dictionary
     variable_dict = mcf_init_add.make_user_variable(
@@ -150,14 +152,15 @@ def modified_causal_forest(
         reduce_split_sample, reduce_split_sample_pred_share, reduce_training,
         reduce_training_share, reduce_prediction, reduce_prediction_share,
         reduce_largest_group_train, reduce_largest_group_train_share,
-        iate_flag, iate_se_flag, _l_centering_uncenter, d_type, ct_grid_nn,
+        iate_flag, iate_se_flag, l_centering_undo_iate, d_type, ct_grid_nn,
         ct_grid_w, ct_grid_dr, support_adjust_limits, l_centering_replication,
-        effiate_flag)
+        effiate_flag, _return_iate_sp)
 # Set defaults for many control variables of the MCF & define variables
 
     c_dict, v_dict, text_to_print = mcf_init.get_controls(controls_dict,
                                                           variable_dict)
     ofs = c_dict['outfilesummary']
+
 # Some descriptive stats of input and direction of output file
     if c_dict['with_output']:
         if c_dict['print_to_file']:
@@ -165,7 +168,8 @@ def modified_causal_forest(
             if c_dict['print_to_terminal']:
                 sys.stdout = gp.OutputTerminalFile(c_dict['outfiletext'])
             else:
-                outfiletext = open(c_dict['outfiletext'], 'w')
+                outfiletext = open(c_dict['outfiletext'], 'a',
+                                   encoding="utf-8")
                 sys.stdout = outfiletext
     if c_dict['reduce_split_sample']:
         outdatei1 = c_dict['indata'][:-4] + 'estredu.csv'
@@ -223,6 +227,10 @@ def modified_causal_forest(
         c_dict['max_cats_cont_vars'] = loaded_tuple[12]
         lc_forest = loaded_tuple[13]
         old_y_name, new_y_name = loaded_tuple[14], loaded_tuple[15]
+        v_dict['y_tree_name'] = loaded_tuple[16]
+        c_dict['l_centering'] = loaded_tuple[17]
+        if c_dict['l_centering'] is False:
+            c_dict['l_centering_uncenter'] = False
     else:
         d_in_values = no_val_dict = q_inv_dict = q_inv_cr_dict = None
         prime_values_dict = unique_val_dict = common_support_list = None
@@ -281,7 +289,8 @@ def modified_causal_forest(
             _, x_variables_out = gp.screen_variables(
                 indata2, v_dict['x_name'], c_dict['check_perfectcorr'],
                 c_dict['min_dummy_obs'], c_dict['with_output'])
-            if x_variables_out != []:
+            # if (x_variables_out != []):
+            if x_variables_out:
                 v_dict, var_x_type, var_x_values, c_dict = (
                     mcf_data.adjust_variables(v_dict, var_x_type, var_x_values,
                                               c_dict, x_variables_out))
@@ -527,7 +536,8 @@ def modified_causal_forest(
                  no_val_dict, q_inv_dict, q_inv_cr_dict, prime_values_dict,
                  unique_val_dict, common_support_list, z_new_name_dict,
                  z_new_dic_dict, c_dict['max_cats_cont_vars'], lc_forest,
-                 old_y_name, new_y_name), save=True,
+                 old_y_name, new_y_name, v_dict['y_tree_name'],
+                 c_dict['l_centering']), save=True,
                 output=c_dict['with_output'])
         if reg_round:
             del prob_score, d_train_tree, common_support_list, unique_val_dict
@@ -571,12 +581,15 @@ def modified_causal_forest(
                     mcf_gate.marg_gates_est(
                         forest, fill_y_sample, preddata3, v_dict, c_dict,
                         x_name_mcf, var_x_type, var_x_values, w_ate)
+                    mcf_gate_tables.gate_tables_nice(c_dict, gate=False)
                     del forest
                 time9_marg = time.time()
                 if c_dict['gate_yes']:
                     gate, gate_se = mcf_gate.gate_est(
                         weights, preddata3, y_train, cl_train, w_train, v_dict,
                         c_dict, var_x_type, var_x_values, w_ate, ate, ate_se)
+                    if c_dict['with_output']:
+                        mcf_gate_tables.gate_tables_nice(c_dict, gate=True)
                 else:
                     gate = gate_se = None
                 time9_gate = time.time()
@@ -584,9 +597,10 @@ def modified_causal_forest(
                 if not reg_round:
                     w_ate = None
                 (pred_outfile, pot_y_, pot_y_var_, iate_, iate_se_,
-                 names_pot_iate_) = mcf_iate.iate_est_mp(
+                 names_pot_iate_, preddata_all) = mcf_iate.iate_est_mp(
                     weights, preddata3, y_train, cl_train, w_train, v_dict,
-                    c_dict, w_ate, pot_y_prev=pot_y)
+                    c_dict, w_ate, pot_y_prev=pot_y, lc_forest=lc_forest,
+                    var_x_type=var_x_type)
                 if reg_round:
                     pot_y, pot_y_var = pot_y_, pot_y_var_
                     iate, iate_se = iate_, iate_se_
@@ -596,7 +610,7 @@ def modified_causal_forest(
             else:
                 pot_y = pot_y_var = iate = iate_se = None
                 eff_iate = eff_pot_y = None
-                pred_outfile = names_pot_iate = None
+                pred_outfile = names_pot_iate = preddata_all = None
             del _, w_ate
             if reg_round:
                 time9_iate = time.time()
@@ -619,10 +633,12 @@ def modified_causal_forest(
                 time10 = time.time()
         else:
             time7 = time8 = time9_ate = time9_marg = time9_gate = time.time()
-            time9_iate = time9_bal = time10 = time.time()
-            time3_2 = time9_iate_2 = time.time()
+            time9_iate = time9_bal = time10 = time3_2 = time.time()
             ate = ate_se = gate = gate_se = iate = iate_se = pot_y = None
             pot_y_var = pred_outfile = eff_iate = eff_pot_y = None
+            preddata_all = names_pot_iate = None
+    if not c_dict['effiate_flag']:
+        time9_iate_2 = time.time()
     timetot = time9_iate_2 if c_dict['effiate_flag'] else time10
     # Print timing information
     time_string = ['Data preparation and stats I:    ',
@@ -658,10 +674,10 @@ def modified_causal_forest(
             os.rmdir(temppfad)
         except OSError:
             if c_dict['with_output'] and c_dict['verbose']:
-                print("Removal of the temorary directory %s failed" % temppfad)
+                print(f"Removal of the temorary directory {temppfad:s} failed")
         else:
             if c_dict['with_output'] and c_dict['verbose']:
-                print("Successfully removed the directory %s" % temppfad)
+                print(f"Successfully removed the directory {temppfad:s}")
     else:
         if c_dict['with_output'] and c_dict['verbose']:
             print('Temporary directory does not exist.')
@@ -696,7 +712,7 @@ def modified_causal_forest(
             outfiletext.close()
         sys.stdout = orig_stdout
     return (ate, ate_se, gate, gate_se, iate, iate_se, pot_y, pot_y_var,
-            pred_outfile, eff_pot_y, eff_iate)
+            pred_outfile, eff_pot_y, eff_iate, names_pot_iate, preddata_all)
 
 
 def save_train_data_for_pred(data_file, v_dict, c_dict, prob_score,
@@ -720,3 +736,230 @@ def save_train_data_for_pred(data_file, v_dict, c_dict, prob_score,
                                      index=False)
     np.save(c_dict['save_forest_file_ps'], prob_score)
     np.save(c_dict['save_forest_file_d_train_tree'], d_train_tree)
+
+
+class ModifiedCausalForest:
+    """Estimate mcf in OOP style."""
+    def __init__(
+            self, id_name=None, cluster_name=None, w_name=None, d_name=None,
+            d_type='discrete', y_tree_name=None, y_name=None, x_name_ord=None,
+            x_name_unord=None, x_name_always_in_ord=None, z_name_list=None,
+            x_name_always_in_unord=None, z_name_split_ord=None,
+            z_name_split_unord=None, z_name_mgate=None, z_name_amgate=None,
+            x_name_remain_ord=None, x_name_remain_unord=None,
+            x_balance_name_ord=None, x_balance_name_unord=None,
+            alpha_reg_min=0.1, alpha_reg_max=0.2, alpha_reg_grid=2,
+            atet_flag=False, balancing_test=True, bin_corr_threshold=0.1,
+            bin_corr_yes=True, boot=1000, ci_level=0.9, check_perfectcorr=True,
+            choice_based_sampling=False, choice_based_weights=None,
+            clean_data_flag=True, cluster_std=False, cond_var_flag=True,
+            ct_grid_nn=10, ct_grid_w=10, ct_grid_dr=100,
+            datpfad=None, effiate_flag=True, fs_other_sample_share=0.2,
+            fs_other_sample=True, fs_rf_threshold=0, fs_yes=None,
+            forest_files=None, gatet_flag=False,
+            gmate_no_evaluation_points=50, gmate_sample_share=None,
+            iate_flag=True, iate_se_flag=True, indata=None, knn_flag=True,
+            knn_min_k=10, knn_const=1, l_centering=True,
+            l_centering_share=0.25, l_centering_cv_k=5,
+            l_centering_new_sample=False, l_centering_replication=True,
+            l_centering_undo_iate=True, m_min_share=-1, m_max_share=-1,
+            m_grid=2, m_random_poisson=True, match_nn_prog_score=True,
+            max_cats_z_vars=None, max_weight_share=0.05,
+            mce_vart=1, min_dummy_obs=10,  mp_parallel=None,
+            n_min_grid=1, n_min_min=-1, n_min_max=-1, nn_main_diag_only=False,
+            nw_kern_flag=1, nw_bandw=None, outfiletext=None,
+            outpfad=None, output_type=2, panel_data=False, panel_in_rf=True,
+            preddata=None, p_diff_penalty=None, post_est_stats=True,
+            post_plots=True, post_kmeans_yes=True, post_kmeans_max_tries=1000,
+            post_kmeans_no_of_groups=None, post_kmeans_replications=10,
+            post_random_forest_vi=True, predict_mcf=True,
+            reduce_prediction=False, reduce_prediction_share=0.5,
+            reduce_split_sample=False, reduce_split_sample_pred_share=0.5,
+            reduce_training=False, reduce_training_share=0.5,
+            relative_to_first_group_only=True, reduce_largest_group_train=False,
+            reduce_largest_group_train_share=0.5, save_forest=False,
+            screen_covariates=True, se_boot_ate=False, se_boot_gate=False,
+            se_boot_iate=False, smooth_gates=True, smooth_gates_bandwidth=1,
+            smooth_gates_no_evaluation_points=50, random_thresholds=None,
+            subsample_factor_forest=None, subsample_factor_eval=False,
+            support_check=1, support_min_p=None, support_quantil=1,
+            support_max_del_train=0.5, support_adjust_limits=None,
+            train_mcf=True, variable_importance_oob=False, weighted=False,
+            _share_forest_sample=0.5, _weight_as_sparse=True,
+            _mp_vim_type=None, _mp_weights_type=1, _mp_weights_tree_batch=None,
+            _verbose=True, _fontsize=2, _descriptive_stats=True,
+            _no_filled_plot=20, _show_plots=True,
+            _smaller_sample=0, _with_output=True, _dpi=500,
+            _max_cats_cont_vars=None, _max_save_values=50,
+            _seed_sample_split=67567885, _mp_ray_del=None,
+            _mp_ray_shutdown=None, _mp_ray_objstore_multiplier=None,
+            _return_iate_sp=False):
+        self.train_mcf = train_mcf
+        self.predict_mcf = predict_mcf
+        self.params = {
+            'id_name': id_name,
+            'cluster_name': cluster_name,
+            'w_name': w_name,
+            'd_name': d_name,
+            'd_type': d_type,
+            'y_tree_name': y_tree_name,
+            'y_name': y_name,
+            'x_name_ord': x_name_ord,
+            'x_name_unord': x_name_unord,
+            'x_name_always_in_ord': x_name_always_in_ord,
+            'z_name_list': z_name_list,
+            'x_name_always_in_unord': x_name_always_in_unord,
+            'z_name_split_ord': z_name_split_ord,
+            'z_name_split_unord': z_name_split_unord,
+            'z_name_mgate': z_name_mgate,
+            'z_name_amgate': z_name_amgate,
+            'x_name_remain_ord': x_name_remain_ord,
+            'x_name_remain_unord': x_name_remain_unord,
+            'x_balance_name_ord': x_balance_name_ord,
+            'x_balance_name_unord': x_balance_name_unord,
+            'alpha_reg_min': alpha_reg_min,
+            'alpha_reg_max': alpha_reg_max,
+            'alpha_reg_grid': alpha_reg_grid,
+            'atet_flag': atet_flag,
+            'balancing_test': balancing_test,
+            'bin_corr_threshold': bin_corr_threshold,
+            'bin_corr_yes': bin_corr_yes,
+            'boot': boot,
+            'ci_level': ci_level,
+            'check_perfectcorr': check_perfectcorr,
+            'choice_based_sampling': choice_based_sampling,
+            'choice_based_weights': choice_based_weights,
+            'clean_data_flag': clean_data_flag,
+            'cluster_std': cluster_std,
+            'cond_var_flag': cond_var_flag,
+            'ct_grid_nn': ct_grid_nn,
+            'ct_grid_w': ct_grid_w,
+            'ct_grid_dr': ct_grid_dr,
+            'datpfad': datpfad,
+            'effiate_flag': effiate_flag,
+            'fs_other_sample_share': fs_other_sample_share,
+            'fs_other_sample': fs_other_sample,
+            'fs_rf_threshold': fs_rf_threshold,
+            'fs_yes': fs_yes,
+            'forest_files': forest_files,
+            'gatet_flag': gatet_flag,
+            'gmate_no_evaluation_points': gmate_no_evaluation_points,
+            'gmate_sample_share': gmate_sample_share,
+            'iate_flag': iate_flag,
+            'iate_se_flag': iate_se_flag,
+            'indata': indata,
+            'knn_flag': knn_flag,
+            'knn_min_k': knn_min_k,
+            'knn_const': knn_const,
+            'l_centering': l_centering,
+            'l_centering_share': l_centering_share,
+            'l_centering_cv_k': l_centering_cv_k,
+            'l_centering_new_sample': l_centering_new_sample,
+            'l_centering_replication': l_centering_replication,
+            'l_centering_undo_iate': l_centering_undo_iate,
+            'm_min_share': m_min_share,
+            'm_max_share': m_max_share,
+            'm_grid': m_grid,
+            'm_random_poisson': m_random_poisson,
+            'match_nn_prog_score': match_nn_prog_score,
+            'max_cats_z_vars': max_cats_z_vars,
+            'max_weight_share': max_weight_share,
+            'mce_vart': mce_vart,
+            'min_dummy_obs': min_dummy_obs,
+            'mp_parallel': mp_parallel,
+            'n_min_grid': n_min_grid,
+            'n_min_min': n_min_min,
+            'n_min_max': n_min_max,
+            'nn_main_diag_only': nn_main_diag_only,
+            'nw_kern_flag': nw_kern_flag,
+            'nw_bandw': nw_bandw,
+            'outfiletext': outfiletext,
+            'outpfad': outpfad,
+            'output_type': output_type,
+            'panel_data': panel_data,
+            'panel_in_rf': panel_in_rf,
+            'preddata': preddata,
+            'p_diff_penalty': p_diff_penalty,
+            'post_est_stats': post_est_stats,
+            'post_plots': post_plots,
+            'post_kmeans_yes': post_kmeans_yes,
+            'post_kmeans_max_tries': post_kmeans_max_tries,
+            'post_kmeans_no_of_groups': post_kmeans_no_of_groups,
+            'post_kmeans_replications': post_kmeans_replications,
+            'post_random_forest_vi': post_random_forest_vi,
+            'predict_mcf': predict_mcf,
+            'reduce_prediction': reduce_prediction,
+            'reduce_prediction_share': reduce_prediction_share,
+            'reduce_split_sample': reduce_split_sample,
+            'reduce_split_sample_pred_share': reduce_split_sample_pred_share,
+            'reduce_training': reduce_training,
+            'reduce_training_share': reduce_training_share,
+            'relative_to_first_group_only': relative_to_first_group_only,
+            'reduce_largest_group_train': reduce_largest_group_train,
+            'reduce_largest_group_train_share': reduce_largest_group_train_share,
+            'save_forest': save_forest,
+            'screen_covariates': screen_covariates,
+            'se_boot_ate': se_boot_ate,
+            'se_boot_gate': se_boot_gate,
+            'se_boot_iate': se_boot_iate,
+            'smooth_gates': smooth_gates,
+            'smooth_gates_bandwidth': smooth_gates_bandwidth,
+            'smooth_gates_no_evaluation_points': smooth_gates_no_evaluation_points,
+            'random_thresholds': random_thresholds,
+            'subsample_factor_forest': subsample_factor_forest,
+            'subsample_factor_eval': subsample_factor_eval,
+            'support_check': support_check,
+            'support_min_p': support_min_p,
+            'support_quantil': support_quantil,
+            'support_max_del_train': support_max_del_train,
+            'support_adjust_limits': support_adjust_limits,
+            'train_mcf': train_mcf,
+            'variable_importance_oob': variable_importance_oob,
+            'weighted': weighted,
+            '_share_forest_sample': _share_forest_sample,
+            '_weight_as_sparse': _weight_as_sparse,
+            '_mp_vim_type': _mp_vim_type,
+            '_mp_weights_type': _mp_weights_type,
+            '_mp_weights_tree_batch': _mp_weights_tree_batch,
+            '_verbose': _verbose,
+            '_fontsize': _fontsize,
+            '_descriptive_stats': _descriptive_stats,
+            '_no_filled_plot': _no_filled_plot,
+            '_show_plots': _show_plots,
+            '_smaller_sample': _smaller_sample,
+            '_with_output': _with_output,
+            '_dpi': _dpi,
+            '_max_cats_cont_vars': _max_cats_cont_vars,
+            '_max_save_values': _max_save_values,
+            '_seed_sample_split': _seed_sample_split,
+            '_mp_ray_del': _mp_ray_del,
+            '_mp_ray_shutdown': _mp_ray_shutdown,
+            '_mp_ray_objstore_multiplier': _mp_ray_objstore_multiplier}
+
+    def train(self):
+        """Train the mcf without prediction."""
+        self.params['train_mcf'] = True
+        self.params['predict_mcf'] = False
+        modified_causal_forest(**self.params)
+
+    def predict(self):
+        """Predict from an already trained mcf."""
+        self.params['train_mcf'] = False
+        self.params['predict_mcf'] = True
+        (ate, ate_se, gate, gate_se, iate, iate_se, pot_y, pot_y_var,
+         pred_outfile, eff_pot_y, eff_iate, names_pot_iate, preddata_all
+                ) = modified_causal_forest(**self.params)
+        return (ate, ate_se, gate, gate_se, iate, iate_se, pot_y, pot_y_var,
+                pred_outfile, eff_pot_y, eff_iate, names_pot_iate,
+                preddata_all)
+
+    def train_predict(self):
+        """Train and predict mcf in one go (recommended)."""
+        self.params['train_mcf'] = True
+        self.params['predict_mcf'] = True
+        (ate, ate_se, gate, gate_se, iate, iate_se, pot_y, pot_y_var,
+         pred_outfile, eff_pot_y, eff_iate, names_pot_iate, preddata_all
+                ) = modified_causal_forest(**self.params)
+        return (ate, ate_se, gate, gate_se, iate, iate_se, pot_y, pot_y_var,
+                pred_outfile, eff_pot_y, eff_iate, names_pot_iate,
+                preddata_all)
