@@ -63,21 +63,21 @@ def black_box_allocation(indata, preddata, c_dict, v_dict, seed):
                 maxworkers = c_dict['no_parallel']
                 if not ray.is_initialized():
                     ray.init(num_cpus=maxworkers, include_dashboard=False)
-                    obs = len(po_np)
-                    po_np_ref, data_df_ref = ray.put(po_np), ray.put(data_df)
-                    still_running = [ray_bb_allocation_boot.remote(
-                        b_idx, obs, po_np_ref, data_df_ref, c_dict, v_dict)
-                            for b_idx in range(c_dict['bb_bootstraps'])]
-                    idx, allocation_b = 0, [None] * c_dict['bb_bootstraps']
-                    while len(still_running) > 0:
-                        finished, still_running = ray.wait(still_running)
-                        finished_res = ray.get(finished)
-                        for ret_all_i in finished_res:
-                            if c_dict['with_output']:
-                                gp.share_completed(idx+1,
-                                                   c_dict['bb_bootstraps'])
-                            allocation_b[idx] = ret_all_i
-                            idx += 1
+                obs = len(po_np)
+                po_np_ref, data_df_ref = ray.put(po_np), ray.put(data_df)
+                still_running = [ray_bb_allocation_boot.remote(
+                    b_idx, obs, po_np_ref, data_df_ref, c_dict, v_dict)
+                        for b_idx in range(c_dict['bb_bootstraps'])]
+                idx, allocation_b = 0, [None] * c_dict['bb_bootstraps']
+                while len(still_running) > 0:
+                    finished, still_running = ray.wait(still_running)
+                    finished_res = ray.get(finished)
+                    for ret_all_i in finished_res:
+                        if c_dict['with_output']:
+                            gp.share_completed(idx+1,
+                                               c_dict['bb_bootstraps'])
+                        allocation_b[idx] = ret_all_i
+                        idx += 1
             else:   # no multiprocessing
                 allocation_b = []
                 for b_idx in range(c_dict['bb_bootstraps']):
@@ -335,6 +335,13 @@ def largest_gain_rest_idx_fct(order_treat, largest_gain_alloc, max_by_cat,
     return largest_gain_rest
 
 
+def po_alloc_draw(no_obs, no_treat, effect_vs_0_np, effect_vs_0_se_np, rng):
+    """Draw (normalized) policy scores"""
+    po_alloc_np = np.zeros((no_obs, no_treat))
+    po_alloc_np[:, 1:] = rng.normal(effect_vs_0_np, effect_vs_0_se_np)
+    return po_alloc_np
+
+
 def bb_allocation(po_np, data_df, c_dict, v_dict, rng):
     """
     Generate the various black-box allocations.
@@ -363,7 +370,13 @@ def bb_allocation(po_np, data_df, c_dict, v_dict, rng):
     else:
         treatment = np.int64(data_df[v_dict['d_name']].to_numpy().flatten())
         allocations.append(observed_fct(treatment))
-    largest_gain = largest_gain_fct(po_np)
+    if c_dict['bb_stochastic']:
+        po_alloc_np = po_alloc_draw(
+            no_obs, no_treat, data_df[v_dict['effect_vs_0']].to_numpy(),
+            data_df[v_dict['effect_vs_0_se']].to_numpy(), rng)
+    else:
+        po_alloc_np = po_np
+    largest_gain = largest_gain_fct(po_alloc_np)
     allocations.append(largest_gain)
     allocations.append(random_fct(no_treat, no_obs, rng))
     if c_dict['restricted']:
@@ -371,12 +384,12 @@ def bb_allocation(po_np, data_df, c_dict, v_dict, rng):
             np.floor(no_obs * np.array(c_dict['max_shares'])))
         allocations.append(random_rest_fct(no_treat, no_obs, max_by_cat, rng))
         allocations.append(largest_gain_rest_fct(
-            po_np, no_treat, no_obs, max_by_cat, largest_gain))
+            po_alloc_np, no_treat, no_obs, max_by_cat, largest_gain))
         allocations.append(largest_gain_rest_random_order_fct(
-            po_np, no_treat, no_obs, max_by_cat, largest_gain, rng))
+            po_alloc_np, no_treat, no_obs, max_by_cat, largest_gain, rng))
         if v_dict['bb_rest_variable']:
             allocations.append(largest_gain_rest_other_var_fct(
-                po_np, no_treat, max_by_cat, v_dict, largest_gain, data_df))
+                po_alloc_np, no_treat, max_by_cat, v_dict, largest_gain, data_df))
     if v_dict['polscore_desc_name'] is not None:
         po_descr_np = data_df[v_dict['polscore_desc_name']].to_numpy()
     else:
@@ -438,6 +451,8 @@ def compute_outcomes(alloc, po_np, po_desc_np, treatment, no_of_treat, obs,
 def compute_alloc_other_outcomes(var_name, po_np, no_of_treat, alloc,
                                  changers=None, treatment=None):
     """Compute effects using additional estimated potential outcomes."""
+    if treatment is None:
+        changers = None
     number_var = round(len(var_name) / no_of_treat)
     assert len(var_name) == po_np.shape[1], ('Wrong dimensions of additional'
                                              + f' outcome variable {var_name}')
