@@ -39,7 +39,7 @@ def optpoltree(
     st_yes=True, st_depth=5, st_min_leaf_size=None, max_shares=None,
     costs_of_treat=0, costs_of_treat_mult=1, only_if_sig_better_vs_0=False,
     sig_level_vs_0=0.05, bb_yes=True, bb_rest_variable=None,
-    ft_bootstraps=0, st_bootstraps=0, bb_bootstraps=499,
+    ft_bootstraps=0, st_bootstraps=0, bb_bootstraps=499, bb_stochastic=False,
         _smaller_sample=None, _with_output=False):
     """Compute the optimal policy tree."""
     freeze_support()
@@ -59,15 +59,14 @@ def optpoltree(
         how_many_parallel, parallel_processing, output_type, outpath, datpath,
         indata, preddata, outfiletext, _with_output, screen_covariates,
         check_perfectcorr, clean_data_flag, min_dummy_obs,
-        ft_no_of_evalupoints,
-        max_shares, ft_depth, costs_of_treat, costs_of_treat_mult,
-        with_numba, ft_min_leaf_size, only_if_sig_better_vs_0, sig_level_vs_0,
-        save_pred_to_file, mp_with_ray, st_yes, st_depth, st_min_leaf_size,
-        ft_yes, bb_yes, ft_bootstraps, st_bootstraps, bb_bootstraps)
+        ft_no_of_evalupoints, max_shares, ft_depth, costs_of_treat,
+        costs_of_treat_mult, with_numba, ft_min_leaf_size,
+        only_if_sig_better_vs_0, sig_level_vs_0, save_pred_to_file,
+        mp_with_ray, st_yes, st_depth, st_min_leaf_size, ft_yes, bb_yes,
+        ft_bootstraps, st_bootstraps, bb_bootstraps, bb_stochastic)
     variables = variable_dict(
         id_name, polscore_name, polscore_desc_name, d_name, x_ord_name,
         x_unord_name, effect_vs_0, effect_vs_0_se, bb_rest_variable)
-
     # Set defaults for many control variables of the MCF & define variables
     c_dict, v_dict = get_controls(controls, variables)
 
@@ -75,11 +74,11 @@ def optpoltree(
     if c_dict['with_output']:
         if c_dict['print_to_file']:
             orig_stdout = sys.stdout
-            gp.delete_file_if_exists(c_dict['outfiletext'])
+            # gp.delete_file_if_exists(c_dict['outfiletext'])
             if c_dict['print_to_terminal']:
                 sys.stdout = gp.OutputTerminalFile(c_dict['outfiletext'])
             else:
-                outfiletext = open(c_dict['outfiletext'], 'w')
+                outfiletext = open(c_dict['outfiletext'], 'a')
                 sys.stdout = outfiletext
     if c_dict['with_output'] and (c_dict['ft_yes'] or dict['st_yes']):
         print('\nParameter for Optimal Policy Tree:')
@@ -104,7 +103,7 @@ def optpoltree(
             'bb_rest_variable']
         names_to_check_pred = names_to_check_pred + v_dict[
             'bb_rest_variable']
-    if c_dict['only_if_sig_better_vs_0']:
+    if c_dict['only_if_sig_better_vs_0'] or c_dict['bb_stochastic']:
         names_to_check_train = names_to_check_train + v_dict[
             'effect_vs_0'] + v_dict['effect_vs_0_se']
     if v_dict['d_name'] is not None:
@@ -504,7 +503,14 @@ def get_controls(c_dict, v_dict):
                 raise Exception('Wrong dimension of variables effect_vs_0')
             if len(v_dict['effect_vs_0_se']) != (no_of_treatments-1):
                 raise Exception('Wrong dimension of variables effect_vs_0_se')
-
+    if c_dict['bb_stochastic'] is not True:
+        c_dict['bb_stochastic'] = False
+    if c_dict['bb_stochastic']:
+        if v_dict['effect_vs_0_se'] in (None, [], ()):
+            raise Exception('effect_vs_0_se must be available for stochastic' +
+                           ' simulations.')
+        if len(v_dict['effect_vs_0_se']) != (no_of_treatments-1):
+            raise Exception('Wrong dimension of variables effect_vs_0')
     c_dict['bb_bootstraps'] = recode_bootstrap(c_dict['bb_bootstraps'], 499)
     c_dict['ft_bootstraps'] = recode_bootstrap(c_dict['ft_bootstraps'], 0)
     c_dict['st_bootstraps'] = recode_bootstrap(c_dict['st_bootstraps'], 0)
@@ -584,7 +590,8 @@ def controls_into_dic(how_many_parallel, parallel_processing,
                       ft_min_leaf_size, only_if_sig_better_vs_0,
                       sig_level_vs_0, save_pred_to_file, mp_with_ray,
                       st_yes, st_depth, st_min_leaf_size, ft_yes, bb_yes,
-                      ft_bootstraps, st_bootstraps, bb_bootstraps):
+                      ft_bootstraps, st_bootstraps, bb_bootstraps,
+                      bb_stochastic):
     """Build dictionary containing control parameters for later easier use."""
     control_dic = {
         'no_parallel': how_many_parallel, 'parallel': parallel_processing,
@@ -602,6 +609,7 @@ def controls_into_dic(how_many_parallel, parallel_processing,
         'ft_min_leaf_size': ft_min_leaf_size,  'st_yes': st_yes,
         'st_min_leaf_size': st_min_leaf_size, 'st_depth': st_depth,
         'bb_yes': bb_yes, 'ft_bootstraps': ft_bootstraps,
-        'st_bootstraps': st_bootstraps, 'bb_bootstraps': bb_bootstraps
-                   }
+        'st_bootstraps': st_bootstraps, 'bb_bootstraps': bb_bootstraps,
+        'bb_stochastic': bb_stochastic
+        }
     return control_dic
